@@ -123,7 +123,7 @@ def create_assessment(
     # Check that there are not any assessments for this submission
     if Assessment.objects.filter(submission_uuid=submission_uuid, score_type=SELF_TYPE).exists():
         msg = (
-            u"Cannot submit a self-assessment for the submission {uuid} "
+            "Cannot submit a self-assessment for the submission {uuid} "
             "because another self-assessment already exists for that submission."
         ).format(uuid=submission_uuid)
         raise SelfAssessmentRequestError(msg)
@@ -133,21 +133,21 @@ def create_assessment(
         submission = get_submission_and_student(submission_uuid)
         if submission['student_item']['student_id'] != user_id:
             msg = (
-                u"Cannot submit a self-assessment for the submission {uuid} "
-                u"because it was created by another learner "
-                u"(submission learner ID {student_id} does not match your "
-                u"learner id {other_id})"
+                "Cannot submit a self-assessment for the submission {uuid} "
+                "because it was created by another learner "
+                "(submission learner ID {student_id} does not match your "
+                "learner id {other_id})"
             ).format(
                 uuid=submission_uuid,
                 student_id=submission['student_item']['student_id'],
                 other_id=user_id
             )
             raise SelfAssessmentRequestError(msg)
-    except SubmissionNotFoundError:
+    except SubmissionNotFoundError as ex:
         msg = (
-            u"Could not submit a self-assessment because no submission exists with UUID {uuid}"
+            "Could not submit a self-assessment because no submission exists with UUID {uuid}"
         ).format(uuid=submission_uuid)
-        raise SelfAssessmentRequestError()
+        raise SelfAssessmentRequestError() from ex
 
     try:
         assessment = _complete_assessment(
@@ -163,17 +163,17 @@ def create_assessment(
     except InvalidRubric as ex:
         msg = "Invalid rubric definition: " + str(ex)
         logger.warning(msg, exc_info=True)
-        raise SelfAssessmentRequestError(msg)
+        raise SelfAssessmentRequestError(msg) from ex
     except InvalidRubricSelection as ex:
         msg = "Selected options do not match the rubric: " + str(ex)
         logger.warning(msg, exc_info=True)
-        raise SelfAssessmentRequestError(msg)
-    except DatabaseError:
+        raise SelfAssessmentRequestError(msg) from ex
+    except DatabaseError as ex:
         error_message = (
-            u"Error creating self assessment for submission {}"
+            "Error creating self assessment for submission {}"
         ).format(submission_uuid)
         logger.exception(error_message)
-        raise SelfAssessmentInternalError(error_message)
+        raise SelfAssessmentInternalError(error_message) from ex
 
     # Return the serialized assessment
     return full_assessment_dict(assessment)
@@ -292,12 +292,12 @@ def get_assessment_scores_by_criteria(submission_uuid):
         # Since this is only being sent one score, the median score will be the
         # same as the only score.
         return Assessment.get_median_score_dict(scores)
-    except DatabaseError:
+    except DatabaseError as ex:
         error_message = (
-            u"Error getting self assessment scores for submission {}"
+            "Error getting self assessment scores for submission {}"
         ).format(submission_uuid)
         logger.exception(error_message)
-        raise SelfAssessmentInternalError(error_message)
+        raise SelfAssessmentInternalError(error_message) from ex
 
 
 def _log_assessment(assessment, submission):
@@ -313,9 +313,9 @@ def _log_assessment(assessment, submission):
 
     """
     logger.info(
-        u"Created self-assessment {assessment_id} for learner {user} on "
-        u"submission {submission_uuid}, course {course_id}, item {item_id} "
-        u"with rubric {rubric_content_hash}"
+        "Created self-assessment {assessment_id} for learner {user} on "
+        "submission {submission_uuid}, course {course_id}, item {item_id} "
+        "with rubric {rubric_content_hash}"
         .format(
             assessment_id=assessment.id,
             user=submission['student_item']['student_id'],
